@@ -33,10 +33,11 @@
 #' @export
 #'
 calculateRelatedness <- function(
-    generations = 2, path = NULL, full = TRUE, maternal = FALSE,
-    empirical = FALSE, segregating = TRUE,
-    total_a = 6800 * 1000000, total_m = 16500,
-    weight_a = 1, weight_m = 1, denom_m = FALSE, ...) {
+  generations = 2, path = NULL, full = TRUE, maternal = FALSE,
+  empirical = FALSE, segregating = TRUE,
+  total_a = 6800 * 1000000, total_m = 16500,
+  weight_a = 1, weight_m = 1, denom_m = FALSE, ...
+) {
   # If path is not provided, it is calculated as twice the number of generations
   if (is.null(path)) {
     path <- generations * 2
