@@ -12,11 +12,12 @@
 #' @param repairsex A logical flag indicating whether to attempt repairs on sex of the parents
 #' @param addphantoms A logical flag indicating whether to add phantom parents for missing parent IDs.
 #' @param parentswithoutrow A logical flag indicating whether to add parents without a row in the pedigree.
-#' @param  famID Character. Column name for family IDs.
-#' @param  personID Character. Column name for individual IDs.
+#' @param famID Character. Column name for family IDs.
+#' @param personID Character. Column name for individual IDs.
 #' @param momID Character. Column name for maternal IDs.
 #' @param dadID Character. Column name for paternal IDs.
-#'
+#' @param code_male The code value used to represent male sex in the 'sex' column of \code{ped}.
+#' @param code_female The code value used to represent female sex in the 'sex' column of \code{ped}.
 #'
 #' @return Depending on the value of `repair`, either a list containing validation results or a repaired dataframe is returned.
 #' @examples
@@ -32,7 +33,9 @@ checkParentIDs <- function(ped, verbose = FALSE, repair = FALSE,
                            famID = "famID",
                            personID = "ID",
                            momID = "momID",
-                           dadID = "dadID") {
+                           dadID = "dadID",
+                           code_male = NULL,
+                           code_female = NULL) {
   # Standardize column names in the input dataframe
   ped <- standardizeColnames(ped, verbose = verbose)
 
@@ -87,18 +90,27 @@ checkParentIDs <- function(ped, verbose = FALSE, repair = FALSE,
     cat("Step 2: Determining the if moms are the same sex and dads are same sex\n")
   }
   # Determine modal sex values for moms and dads
+
+
   mom_results <- checkParentSex(ped, parent_col = "momID", verbose = verbose)
   dad_results <- checkParentSex(ped, parent_col = "dadID", verbose = verbose)
 
   validation_results$mom_sex <- mom_results$unique_sexes
   validation_results$dad_sex <- dad_results$unique_sexes
-  validation_results$female_var <- mom_results$modal_sex
-  validation_results$male_var <- dad_results$modal_sex
+
   validation_results$wrong_sex_moms <- mom_results$inconsistent_parents
   validation_results$wrong_sex_dads <- dad_results$inconsistent_parents
   validation_results$female_moms <- mom_results$all_same_sex
   validation_results$male_dads <- dad_results$all_same_sex
-
+  if (!is.null(code_male) && !is.null(code_female)) {
+    validation_results$male_var <- code_male
+    validation_results$female_var <- code_female
+    validation_results$sex_code_source <- "user_provided_codes"
+  } else {
+    validation_results$female_var <- mom_results$modal_sex
+    validation_results$male_var <- dad_results$modal_sex
+    validation_results$sex_code_source <- "modal_parent_sex"
+  }
   # Are any parents in both momID and dadID?
   momdad <- intersect(ped$dadID, ped$momID)
   if (length(momdad) > 0 && !is.na(momdad)) {
@@ -173,7 +185,7 @@ checkParentIDs <- function(ped, verbose = FALSE, repair = FALSE,
       }
     }
   }
-  if (addphantoms) {
+  if (addphantoms == TRUE) {
     # Generate new IDs
     newIDbase <- if (is.numeric(ped$ID)) max(ped$ID, na.rm = TRUE) + 1 else paste0("phantom-", seq_len(nrow(ped)))
     # Initialize a dataframe to store new entries
@@ -196,19 +208,37 @@ checkParentIDs <- function(ped, verbose = FALSE, repair = FALSE,
       newID <- if (is.numeric(ped$ID)) newIDbase + added_counter else paste0("phantom-dad-", ped$ID[idx])
       added_counter <- added_counter + 1
       ped$dadID[idx] <- newID
+      if ("famID" %in% names(ped)) {
+        newFAMID <- unique(ped$famID[idx])
+        newFAMID <- newFAMID[!is.na(newFAMID)]
 
-
-      new_entry <- addParentRow(new_entry_base, newID = newID, dadID = NA, momID = NA, sex = inferred_sex)
+        new_entry <- addParentRow(new_entry_base, newID = newID, dadID = NA, momID = NA, sex = inferred_sex, famID = newFAMID)
+      } else {
+        new_entry <- addParentRow(new_entry_base, newID = newID, dadID = NA, momID = NA, sex = inferred_sex)
+      }
       new_entries <- rbind(new_entries, new_entry)
     }
 
     # Add moms when missing
-    inferred_sex <- if (length(validation_results$female_var) > 0 && !is.na(validation_results$female_var)) validation_results$female_var else 0
+    inferred_sex <- if (length(validation_results$female_var) > 0 && !is.na(validation_results$female_var)) {
+      validation_results$female_var
+    } else {
+      0
+    }
+
     for (idx in which(!is.na(ped$dadID) & is.na(ped$momID))) {
       newID <- if (is.numeric(ped$ID)) newIDbase + added_counter else paste0("phantom-mom-", ped$ID[idx])
       added_counter <- added_counter + 1
       ped$momID[idx] <- newID
-      new_entry <- addParentRow(new_entry_base, newID = newID, dadID = NA, momID = NA, sex = inferred_sex)
+
+      if ("famID" %in% names(ped)) {
+        newFAMID <- unique(ped$famID[idx])
+        newFAMID <- newFAMID[!is.na(newFAMID)]
+
+        new_entry <- addParentRow(new_entry_base, newID = newID, dadID = NA, momID = NA, sex = inferred_sex, famID = newFAMID)
+      } else {
+        new_entry <- addParentRow(new_entry_base, newID = newID, dadID = NA, momID = NA, sex = inferred_sex)
+      }
       new_entries <- rbind(new_entries, new_entry)
     }
 
@@ -300,7 +330,19 @@ addRowlessParents <- function(ped, verbose, validation_results) {
       )
       inferred_sex <- if ("mom" %in% role) validation_results$female_var else validation_results$male_var
 
-      new_entry <- addParentRow(new_entry_base, newID = pid, dadID = NA, momID = NA, sex = inferred_sex)
+      if ("famID" %in% names(ped)) {
+        newFAMID <- unique(ped$famID[which(ped$momID == pid | ped$dadID == pid)])
+        newFAMID <- newFAMID[!is.na(newFAMID)]
+
+
+        if (length(newFAMID) > 1) {
+          newFAMID <- NA
+        }
+
+        new_entry <- addParentRow(new_entry_base, newID = pid, dadID = NA, momID = NA, sex = inferred_sex, famID = newFAMID)
+      } else {
+        new_entry <- addParentRow(new_entry_base, newID = pid, dadID = NA, momID = NA, sex = inferred_sex)
+      }
 
       new_entries <- rbind(new_entries, new_entry)
     }
@@ -312,7 +354,6 @@ addRowlessParents <- function(ped, verbose, validation_results) {
   }
 
 
-
   return(ped)
 }
 
@@ -324,16 +365,23 @@ addRowlessParents <- function(ped, verbose, validation_results) {
 #' @param sex The new parent's sex value (e.g., 0 for female, 1 for male, or "F"/"M")
 #' @param momID The new parent's mother ID (default is NA)
 #' @param dadID The new parent's father ID (default is NA)
+#' @param famID The new parent's family ID (default is NA)
 #' @return A single-row dataframe for the new parent
 addParentRow <- function(template_row, newID, sex,
                          momID = NA,
-                         dadID = NA) {
+                         dadID = NA,
+                         famID = NA) {
   new_row <- template_row
   new_row[] <- NA # set all columns to NA
   new_row$ID <- newID
-  new_row$momID <- NA
-  new_row$dadID <- NA
+  new_row$momID <- momID
+  new_row$dadID <- dadID
   new_row$sex <- sex
+
+  if ("famID" %in% names(template_row)) {
+    new_row$famID <- famID
+  }
   # You can add more column initializations here if needed
+
   return(new_row)
 }
