@@ -17,7 +17,7 @@ utils::globalVariables(c(".N", ".SD"))
 #' Beyond summary statistics, the function identifies the founding member of
 #' each lineage based on the specified sorting variable (`founder_sort_var`),
 #' defaulting to birth year (`byr`) when available or `personID` otherwise.
-#' Users can retrieve the largest and oldest lineages by setting `n_biggest`
+#' Users can retrieve the largest and oldest lineages by setting `n_fooest`
 #' and `n_oldest`, respectively.
 #'
 #' @inheritParams ped2fam
@@ -41,9 +41,13 @@ utils::globalVariables(c(".N", ".SD"))
 #' @importFrom data.table as.data.table
 #' @aliases summarisePedigrees summarisepedigrees summarizepedigrees
 #' @export
-summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
-                               momID = "momID", dadID = "dadID",
-                               matID = "matID", patID = "patID",
+summarizePedigrees <- function(ped,
+                               famID = "famID",
+                               personID = "ID",
+                               momID = "momID",
+                               dadID = "dadID",
+                               matID = "matID",
+                               patID = "patID",
                                type = c("fathers", "mothers", "families"),
                                byr = NULL,
                                include_founder = FALSE,
@@ -69,10 +73,15 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
     stop("Type must be specified. Options are 'fathers', 'mothers', and 'families'.")
   }
   if (!is.null(byr) && !byr %in% names(ped)) {
-    stop("If byr is specified, byr must be a column in the pedigree data. If you do not want to sort by birth year, set byr = NULL.")
+    stop(
+      "If byr is specified, byr must be a column in the pedigree data. If you do not want to sort by birth year, set byr = NULL."
+    )
   }
-  if (!is.null(founder_sort_var) && !founder_sort_var %in% names(ped)) {
-    stop("If you set founder_sort_var, that variable must be a column in the pedigree data. If you want to sort by using the default, set founder_sort_var = NULL. The default is to sort by birth year if that's present and by personID otherwise.")
+  if (!is.null(founder_sort_var) &&
+    !founder_sort_var %in% names(ped)) {
+    stop(
+      "If you set founder_sort_var, that variable must be a column in the pedigree data. If you want to sort by using the default, set founder_sort_var = NULL. The default is to sort by birth year if that's present and by personID otherwise."
+    )
   }
 
   # user inputs
@@ -90,8 +99,6 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
     founder_sort_var <- byr
   }
 
-
-
   ped <- prepSummarizePedigrees(
     ped = ped,
     type = type,
@@ -108,7 +115,6 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
   ped_dt <- data.table::as.data.table(ped)
 
 
-
   # Initialize...
   ## Output list
   output <- list()
@@ -117,7 +123,9 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
 
 
   if (network_checks == TRUE) {
-    if (verbose == TRUE) message("Performing network validation checks...")
+    if (verbose == TRUE) {
+      message("Performing network validation checks...")
+    }
     output$network_validation <- checkPedigreeNetwork(
       ped,
       personID = personID,
@@ -130,8 +138,11 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
   # Calculate summary statistics for families, maternal lines, and paternal lines
 
   if ("families" %in% type) {
-    if (verbose == TRUE) message("Summarizing families...")
-    family_summary_dt <- calculateSummaryDT(ped_dt,
+    if (verbose == TRUE) {
+      message("Summarizing families...")
+    }
+    family_summary_dt <- calculateSummaryDT(
+      ped_dt,
       group_var = famID,
       skip_var = skip_var,
       five_num_summary = five_num_summary
@@ -139,7 +150,8 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
     # Find the originating member for each line
     if (include_founder == TRUE) {
       family_summary_dt <- summarizeFounder(
-        verbose = verbose, ped_dt = ped_dt,
+        verbose = verbose,
+        ped_dt = ped_dt,
         group_var = famID,
         sort_var = founder_sort_var,
         foo_summary_dt = family_summary_dt
@@ -147,19 +159,25 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
     }
     output$family_summary <- family_summary_dt
     n_families <- nrow(family_summary_dt)
-    if (verbose == TRUE) message("Summarized ", n_families, " families.")
+    if (verbose == TRUE) {
+      message("Summarized ", n_families, " families.")
+    }
   }
 
   if ("mothers" %in% type) {
-    if (verbose == TRUE) message("Summarizing maternal lines...")
-    maternal_summary_dt <- calculateSummaryDT(ped_dt,
+    if (verbose == TRUE) {
+      message("Summarizing maternal lines...")
+    }
+    maternal_summary_dt <- calculateSummaryDT(
+      ped_dt,
       group_var = matID,
       skip_var = skip_var,
       five_num_summary = five_num_summary
     )
     if (include_founder == TRUE) {
       maternal_summary_dt <- summarizeFounder(
-        verbose = verbose, ped_dt = ped_dt,
+        verbose = verbose,
+        ped_dt = ped_dt,
         group_var = matID,
         sort_var = founder_sort_var,
         foo_summary_dt = maternal_summary_dt
@@ -169,18 +187,24 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
 
     n_mothers <- nrow(maternal_summary_dt)
 
-    if (verbose == TRUE) message("Summarized ", n_mothers, " maternal lines.")
+    if (verbose == TRUE) {
+      message("Summarized ", n_mothers, " maternal lines.")
+    }
   }
   if ("fathers" %in% type) {
-    if (verbose == TRUE) message("Summarizing paternal lines...")
-    paternal_summary_dt <- calculateSummaryDT(ped_dt,
+    if (verbose == TRUE) {
+      message("Summarizing paternal lines...")
+    }
+    paternal_summary_dt <- calculateSummaryDT(
+      ped_dt,
       group_var = patID,
       skip_var = skip_var,
       five_num_summary = five_num_summary
     )
     if (include_founder == TRUE) {
       paternal_summary_dt <- summarizeFounder(
-        verbose = verbose, ped_dt = ped_dt,
+        verbose = verbose,
+        ped_dt = ped_dt,
         group_var = patID,
         sort_var = founder_sort_var,
         foo_summary_dt = paternal_summary_dt
@@ -190,7 +214,9 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
     output$paternal_summary <- paternal_summary_dt
 
     n_fathers <- nrow(paternal_summary_dt)
-    if (verbose == TRUE) message("Summarized ", n_fathers, " paternal lines.")
+    if (verbose == TRUE) {
+      message("Summarized ", n_fathers, " paternal lines.")
+    }
   }
 
   ## Check errors
@@ -200,58 +226,42 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
   #                                repair = FALSE, verbose = verbose)
   #  }
 
-  ## oldest
-  if (!is.null(byr) && n_oldest > 0) {
-    if (!is.null(n_families) && "families" %in% type) {
-      if (verbose == TRUE) message("Finding oldest families...")
-      output$oldest_families <- findOldest(
-        foo_summary_dt = family_summary_dt,
-        byr = byr,
-        n_oldest = n_oldest,
-        n_foo = n_families
-      )
-    }
-    if (!is.null(n_mothers) && "mothers" %in% type) {
-      if (verbose == TRUE) message("Finding oldest maternal lines...")
-      output$oldest_maternal <- findOldest(
-        foo_summary_dt = maternal_summary_dt,
-        byr = byr,
-        n_oldest = n_oldest,
-        n_foo = n_mothers
-      )
-    }
-    if (!is.null(n_fathers) && "fathers" %in% type) {
-      if (verbose == TRUE) message("Finding oldest paternal lines...")
-      output$oldest_paternal <- findOldest(
-        foo_summary_dt = paternal_summary_dt,
-        byr = byr,
-        n_oldest = n_oldest,
-        n_foo = n_fathers
-      )
-    }
-  }
+
+  output <- summarizeOldest(
+    byr = byr,
+    n_oldest = n_oldest,
+    n_families = n_families,
+    type = type,
+    verbose = verbose,
+    output = output,
+    family_summary_dt = family_summary_dt,
+    n_mothers = n_mothers,
+    maternal_summary_dt = maternal_summary_dt,
+    n_fathers = n_fathers,
+    paternal_summary_dt = paternal_summary_dt
+  )
 
   # biggest lines
   if (!is.null(n_biggest) && n_biggest > 0) {
     if (!is.null(n_families) && "families" %in% type) {
       output$biggest_families <- findBiggest(
         foo_summary_dt = family_summary_dt,
-        n_biggest = n_biggest,
-        n_foo = n_families
+        n_fooest = n_biggest,
+        n_foo_total = n_families
       )
     }
     if (!is.null(n_mothers) && "mothers" %in% type) {
       output$biggest_maternal <- findBiggest(
         foo_summary_dt = maternal_summary_dt,
-        n_biggest = n_biggest,
-        n_foo = n_mothers
+        n_fooest = n_biggest,
+        n_foo_total = n_mothers
       )
     }
     if (!is.null(n_fathers) && "fathers" %in% type) {
       output$biggest_paternal <- findBiggest(
         foo_summary_dt = paternal_summary_dt,
-        n_biggest = n_biggest,
-        n_foo = n_fathers
+        n_fooest = n_biggest,
+        n_foo_total = n_fathers
       )
     }
   }
@@ -264,16 +274,17 @@ summarizePedigrees <- function(ped, famID = "famID", personID = "ID",
 #' @inheritParams summarizePedigrees
 #' @param data A data.table containing the pedigree data.
 #' @param group_var A character string specifying the column name of the grouping variable.
+#' @param na_rm Logical. If `TRUE`, removes `NA` values when calculating statistics.
 #' @return A data.table containing the summary statistics for all numeric variables.
 #' @keywords internal
 #'
-calculateSummaryDT <- function(data, group_var, skip_var,
-                               five_num_summary = FALSE) {
+calculateSummaryDT <- function(data,
+                               group_var,
+                               skip_var,
+                               five_num_summary = FALSE,
+                               na_rm = TRUE) {
   # Identify numeric columns excluding the group_var and skip_var
-  numeric_cols <- setdiff(
-    names(data)[vapply(data, is.numeric, logical(1))],
-    c(group_var, skip_var)
-  )
+  numeric_cols <- setdiff(names(data)[vapply(data, is.numeric, logical(1))], c(group_var, skip_var))
   summary_stats <- data[,
     {
       count <- .N # Calculate count once per group
@@ -281,21 +292,17 @@ calculateSummaryDT <- function(data, group_var, skip_var,
         x <- .SD[[colname]]
         stats <- list(
           #   count = .N,
-          mean = as.double(base::mean(x, na.rm = TRUE)),
-          median = as.double(stats::median(x, na.rm = TRUE)),
+          mean = as.double(base::mean(x, na.rm = na_rm)),
+          median = as.double(stats::median(x, na.rm = na_rm)),
           #  mode = as.double(stats::mode(x, na.rm = TRUE)),
-          min = ifelse(all(is.na(x)), as.double(NA),
-            as.double(base::min(x, na.rm = TRUE))
-          ),
-          max = ifelse(all(is.na(x)), as.double(NA),
-            as.double(base::max(x, na.rm = TRUE))
-          ),
-          sd = as.double(stats::sd(x, na.rm = TRUE))
+          min = ifelse(all(is.na(x)), as.double(NA), as.double(base::min(x, na.rm = na_rm))),
+          max = ifelse(all(is.na(x)), as.double(NA), as.double(base::max(x, na.rm = na_rm))),
+          sd = as.double(stats::sd(x, na.rm = na_rm))
         )
         if (five_num_summary) {
           stats <- c(stats, list(
-            Q1 = as.double(stats::quantile(x, 0.25, na.rm = TRUE)),
-            Q3 = as.double(stats::quantile(x, 0.75, na.rm = TRUE))
+            Q1 = as.double(stats::quantile(x, 0.25, na.rm = na_rm)),
+            Q3 = as.double(stats::quantile(x, 0.75, na.rm = na_rm))
           ))
         }
         names(stats) <- paste0(colname, "_", names(stats))
@@ -308,9 +315,7 @@ calculateSummaryDT <- function(data, group_var, skip_var,
     .SDcols = numeric_cols
   ]
   # Flatten the nested lists
-  summary_stats <- data.table::as.data.table(summary_stats[, lapply(.SD, unlist),
-    by = group_var
-  ])
+  summary_stats <- data.table::as.data.table(summary_stats[, lapply(.SD, unlist), by = group_var])
   return(summary_stats)
 }
 
@@ -338,13 +343,13 @@ findFounder <- function(data, group_var, sort_var) {
 #' @aliases summarizefounder summariseFounder
 #' @keywords internal
 
-summarizeFounder <- function(ped_dt, group_var, sort_var,
-                             foo_summary_dt, verbose) {
+summarizeFounder <- function(ped_dt,
+                             group_var,
+                             sort_var,
+                             foo_summary_dt,
+                             verbose) {
   if (verbose == TRUE) {
-    message(paste0(
-      "Finding originating members for ",
-      "group_var"
-    ))
+    message(paste0("Finding originating members for ", group_var))
   }
   originating_member_foo <- findFounder(
     data = ped_dt,
@@ -352,116 +357,63 @@ summarizeFounder <- function(ped_dt, group_var, sort_var,
     sort_var = sort_var
   )
   # Merge summary statistics with originating members for additional information
-  foo_summary_dt <- merge(foo_summary_dt,
+  foo_summary_dt <- merge(
+    foo_summary_dt,
     originating_member_foo,
-    by = group_var, suffixes = c("", "_founder")
+    by = group_var,
+    suffixes = c("", "_founder")
   )
   return(foo_summary_dt)
 }
-#' Summarize the maternal lines in a pedigree
+
+
+#' Function to find the most extreme individuals in a pedigree
+#' This function finds the most extreme individuals (oldest or youngest) in a pedigree. It is supposed to be used internally by the \code{summarize_pedigree} function.
 #' @inheritParams summarizePedigrees
-#' @seealso [summarizePedigrees ()]
-#' @export
-#' @aliases summarizematrilines summarisematrilines summariseMatrilines
-summarizeMatrilines <- function(ped, famID = "famID", personID = "ID",
-                                momID = "momID", dadID = "dadID",
-                                matID = "matID", patID = "patID",
-                                byr = NULL, include_founder = FALSE,
-                                founder_sort_var = NULL,
-                                n_biggest = 5, n_oldest = 5, skip_var = NULL,
-                                five_num_summary = FALSE, verbose = FALSE,
-                                network_checks = FALSE) {
-  # Call to wrapper function
-  summarizePedigrees(
-    ped = ped,
-    personID = personID,
-    n_biggest = n_biggest,
-    n_oldest = n_oldest,
-    byr = byr,
-    include_founder = include_founder,
-    momID = momID, dadID = dadID,
-    famID = famID, matID = matID, patID = patID, skip_var = skip_var,
-    type = "mothers", verbose = verbose, five_num_summary = five_num_summary,
-    founder_sort_var = founder_sort_var, network_checks = network_checks
-  )
+#' @param n_foo_total  An integer specifying the total number of individuals in the summary.
+#' @param n_fooest An integer specifying the number of individuals to return in the summary.
+#' @param sort_var A character string specifying the column to sort by.
+#' @param decreasing A logical indicating whether to sort in decreasing order.
+#' @returns A data.table with the top rows selected from \code{foo_summary_dt}.
+#' @keywords internal
+
+
+findFooest <- function(foo_summary_dt,
+                       sort_var,
+                       n_fooest,
+                       n_foo_total = nrow(foo_summary_dt),
+                       decreasing = FALSE) {
+  subset_foo <- try_na(tryCatch(
+    {
+      foo_summary_dt[order(get(sort_var), decreasing = decreasing)][1:min(c(n_fooest, n_foo_total), na.rm = TRUE), ]
+    }, # solves case when only one row is present
+    error = function(e) {
+      foo_summary_dt[1, ]
+    }
+  ))
+
+  return(subset_foo)
 }
 
-
-
-
-#' Summarize the paternal lines in a pedigree
-#' @inheritParams summarizePedigrees
-#' @seealso [summarizePedigrees ()]
-#' @export
-#' @aliases summarizepatrilines summarisepatrilines summarisePatrilines
-summarizePatrilines <- function(ped, famID = "famID", personID = "ID",
-                                momID = "momID", dadID = "dadID",
-                                matID = "matID", patID = "patID",
-                                byr = NULL, founder_sort_var = NULL,
-                                include_founder = FALSE,
-                                n_biggest = 5, n_oldest = 5, skip_var = NULL,
-                                five_num_summary = FALSE, verbose = FALSE,
-                                network_checks = FALSE) {
-  # Call to wrapper function
-  summarizePedigrees(
-    ped = ped,
-    personID = personID,
-    n_biggest = n_biggest,
-    n_oldest = n_oldest,
-    byr = byr,
-    include_founder = include_founder,
-    momID = momID, dadID = dadID,
-    famID = famID, matID = matID, patID = patID, skip_var = skip_var,
-    type = "fathers", verbose = verbose, five_num_summary = five_num_summary,
-    founder_sort_var = founder_sort_var, network_checks = network_checks
-  )
-}
-
-#' Summarize the families in a pedigree
-#' @inheritParams summarizePedigrees
-#' @seealso [summarizePedigrees ()]
-#' @aliases summarizefamilies summarisefamilies summariseFamilies
-#' @export
-summarizeFamilies <- function(ped, famID = "famID", personID = "ID",
-                              momID = "momID", dadID = "dadID",
-                              matID = "matID", patID = "patID",
-                              byr = NULL, founder_sort_var = NULL,
-                              include_founder = FALSE,
-                              n_biggest = 5, n_oldest = 5, skip_var = NULL,
-                              five_num_summary = FALSE, verbose = FALSE,
-                              network_checks = FALSE) {
-  # Call to wrapper function
-  summarizePedigrees(
-    ped = ped,
-    personID = personID,
-    n_biggest = n_biggest,
-    n_oldest = n_oldest,
-    byr = byr,
-    include_founder = include_founder,
-    momID = momID,
-    dadID = dadID,
-    famID = famID,
-    matID = matID,
-    patID = patID,
-    skip_var = skip_var,
-    type = "families",
-    verbose = verbose,
-    five_num_summary = five_num_summary,
-    founder_sort_var = founder_sort_var,
-    network_checks = network_checks
-  )
-}
-# Function to find the oldest individuals in a pedigree
+#' Function to find the oldest individuals in a pedigree
 #' This function finds the oldest families in a pedigree. It is supposed to be used internally by the \code{summarize_pedigree} function.
 #' @inheritParams summarizePedigrees
 #' @param foo_summary_dt A data.table containing the summary statistics.
-#' @param n_foo An integer specifying the number of individuals in the summary.
+#' @param n_fooest An integer specifying the number of individuals in the summary.
+#' @param n_foo_total An integer specifying the total number of individuals in the summary.
 #' @returns a data.table containing the oldest families in the pedigree.
 #' @aliases findoldest
-findOldest <- function(foo_summary_dt, byr, n_oldest, n_foo) {
-  oldest_foo <- try_na(foo_summary_dt[order(get(byr))][1:min(c(n_oldest, n_foo),
-    na.rm = TRUE
-  )])
+findOldest <- function(foo_summary_dt,
+                       byr = "byr",
+                       n_fooest = 5,
+                       n_foo_total = nrow(foo_summary_dt)) {
+  oldest_foo <- findFooest(
+    foo_summary_dt = foo_summary_dt,
+    sort_var = byr,
+    n_foo_total = n_foo_total,
+    n_fooest = n_fooest,
+    decreasing = FALSE
+  )
   return(oldest_foo)
 }
 
@@ -474,11 +426,15 @@ findOldest <- function(foo_summary_dt, byr, n_oldest, n_foo) {
 #' @returns a data.table containing the biggest families in the pedigree.
 #' @aliases findbiggest
 
-findBiggest <- function(foo_summary_dt, n_biggest, n_foo) {
-  biggest_foo <- try_na(
-    foo_summary_dt[order(-get("count"))][1:min(c(n_biggest, n_foo),
-      na.rm = TRUE
-    )]
+findBiggest <- function(foo_summary_dt,
+                        n_fooest = 5,
+                        n_foo_total = nrow(foo_summary_dt)) {
+  biggest_foo <- findFooest(
+    foo_summary_dt = foo_summary_dt,
+    sort_var = "count",
+    n_foo_total = n_foo_total,
+    n_fooest = n_fooest,
+    decreasing = TRUE
   )
   return(biggest_foo)
 }
@@ -492,27 +448,46 @@ prepSummarizePedigrees <- function(ped,
                                    type,
                                    verbose = FALSE,
                                    famID,
-                                   personID, momID, dadID, matID, patID) {
+                                   personID,
+                                   momID,
+                                   dadID,
+                                   matID,
+                                   patID) {
   # Build the pedigree using the provided functions
   if ("families" %in% type && !famID %in% names(ped)) {
-    if (verbose == TRUE) message("Counting families...")
-    ped <- ped2fam(ped,
+    if (verbose == TRUE) {
+      message("Counting families...")
+    }
+    ped <- ped2fam(
+      ped,
       personID = personID,
-      momID = momID, dadID = dadID, famID = famID
+      momID = momID,
+      dadID = dadID,
+      famID = famID
     )
   }
   if ("mothers" %in% type && !matID %in% names(ped)) {
-    if (verbose == TRUE) message("Counting mothers...")
-    ped <- ped2maternal(ped,
+    if (verbose == TRUE) {
+      message("Counting mothers...")
+    }
+    ped <- ped2maternal(
+      ped,
       personID = personID,
-      momID = momID, dadID = dadID, matID = matID
+      momID = momID,
+      dadID = dadID,
+      matID = matID
     )
   }
   if ("fathers" %in% type && !patID %in% names(ped)) {
-    if (verbose == TRUE) message("Counting fathers...")
-    ped <- ped2paternal(ped,
+    if (verbose == TRUE) {
+      message("Counting fathers...")
+    }
+    ped <- ped2paternal(
+      ped,
       personID = personID,
-      momID = momID, dadID = dadID, patID = patID
+      momID = momID,
+      dadID = dadID,
+      patID = patID
     )
   }
 
@@ -520,20 +495,58 @@ prepSummarizePedigrees <- function(ped,
   return(ped)
 }
 
-
-
-#' @rdname summarizePedigrees
-#' @export
-summarisePedigrees <- summarizePedigrees
-
-#' @rdname summarizeFamilies
-#' @export
-summariseFamilies <- summarizeFamilies
-
-#' @rdname summarizeMatrilines
-#' @export
-summariseMatrilines <- summarizeMatrilines
-
-#' @rdname summarizePatrilines
-#' @export
-summarisePatrilines <- summarizePatrilines
+#' Function to summarize the oldest individuals in a pedigree
+#'
+#' @inheritParams summarizePedigrees
+#' @return A data.table containing the summary statistics for all numeric variables.
+#' @keywords internal
+#'
+summarizeOldest <- function(byr = NULL,
+                            n_oldest = 5,
+                            n_families = NULL,
+                            type = NULL,
+                            verbose = FALSE,
+                            output,
+                            family_summary_dt = NULL,
+                            n_mothers = NULL,
+                            maternal_summary_dt = NULL,
+                            n_fathers = NULL,
+                            paternal_summary_dt = NULL) {
+  ## oldest
+  if (!is.null(byr) && n_oldest > 0) {
+    if (!is.null(n_families) && "families" %in% type) {
+      if (verbose == TRUE) {
+        message("Finding oldest families...")
+      }
+      output$oldest_families <- findOldest(
+        foo_summary_dt = family_summary_dt,
+        byr = byr,
+        n_fooest = n_oldest,
+        n_foo_total = n_families
+      )
+    }
+    if (!is.null(n_mothers) && "mothers" %in% type) {
+      if (verbose == TRUE) {
+        message("Finding oldest maternal lines...")
+      }
+      output$oldest_maternal <- findOldest(
+        foo_summary_dt = maternal_summary_dt,
+        byr = byr,
+        n_fooest = n_oldest,
+        n_foo_total = n_mothers
+      )
+    }
+    if (!is.null(n_fathers) && "fathers" %in% type) {
+      if (verbose == TRUE) {
+        message("Finding oldest paternal lines...")
+      }
+      output$oldest_paternal <- findOldest(
+        foo_summary_dt = paternal_summary_dt,
+        byr = byr,
+        n_fooest = n_oldest,
+        n_foo_total = n_fathers
+      )
+    }
+  }
+  return(output)
+}
